==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Priključak %1 nije kompatibilan sa sustavom.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 povezan</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Povezujem...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Isključeno</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj raspored tipkovnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum vrijeme</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-satno vrijeme</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-satno vrijeme</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Postavke vremena</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Omogući mrežu</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogući mrežu</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Mrežne postavke</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Jeste li sigurni da želite isprazniti %1 stavki?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ova se radnja ne može obnoviti</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nepoznati uređaj</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nepoznata količina</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Sve odspoji</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Pokretač</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Popularan način</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efikasan način</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Drži prikazano</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Drži skriveno</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokacija</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Priključci</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Onemogući žično povezivanje</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Omogući žično povezivanje</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Onemogući bežično povezivaqnje</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Omogući bežično povezivanje</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Onemogući mrežu</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Omogući mrežu</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Mrežne postavke</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Uređaj je onemogućen</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Bežična veza: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Žična  veza: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nije spojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Povezujem se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Spojen ali nema pristupa internetu</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mrežni kabel je isključen</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Žična mreža</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Žična mreža %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, %2 min preostalo</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, %2 hr %3 min preostalo</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Punim %1, %2 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Punim %1, %2 hr %3 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Napunjeno</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Punjenje %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet %1, potpuno napunjen</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Prikaži radnu površinu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberniraj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Promijeni račun</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Uređaj</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Uključi zvuk</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Postavke zvuka</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Glasnoća %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Smeće</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Smeće - %1 datoteka</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Smeće - %1 datoteke</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Sustavski pladanj</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Bežična mreža</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bežična mreža %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Priključak %1 nije kompatibilan sa sustavom.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 povezan</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Povezujem...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Isključeno</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj raspored tipkovnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum vrijeme</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-satno vrijeme</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-satno vrijeme</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Postavke vremena</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Jeste li sigurni da želite isprazniti %1 stavki?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Ova se radnja ne može obnoviti</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nepoznati uređaj</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nepoznata količina</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Sve odspoji</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Pokretač</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Popularan način</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efikasan način</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Drži prikazano</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Drži skriveno</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokacija</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Veličina</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Višestruki zasloni</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Moderan način</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Učinkoviti način</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokacija</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Drži prikazano</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Drži skriveno</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Pametno skrivanje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Maleno</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Veliko</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na zaslon gdje je pokazivač</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Samo na glavni zaslon</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, %2 min preostalo</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, %2 hr %3 min preostalo</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Punim %1, %2 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Punim %1, %2 hr %3 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Punjenje %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet %1, potpuno napunjen</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation type="unfinished"/>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Prikaži radnu površinu</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberniraj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Promijeni račun</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Uređaj</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Uključi zvuk</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Postavke zvuka</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Glasnoća %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Smeće</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Smeće - %1 datoteka</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Smeće - %1 datoteke</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Premjesti u smeće</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Prazno</translation>
    </message>
</context>
</TS>
